## cork

[rzeczownik]

1. drzewo korkowe

He had a favorite spot out in the pasture under a cork.
(On miał swoje ulubione miejsce na pastwisku pod drzewem korkowym.)

2. korek (od butelki)

I prefer a wooden cork because you can always reuse it.
(Wolę drewniany korek, ponieważ zawsze można go ponownie użyć.)

[czasownik]

1. zakorkować, zatykać

Remember to cork the bottle after you stop using it.
(Pamiętaj, żeby zakorkować butelkę, kiedy przestaniesz jej używać.)